<?php

namespace Drupal\Tests\message_digest\Kernel;

use Drupal\Core\Test\AssertMailTrait;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\message\Kernel\MessageTemplateCreateTrait;
use Drupal\simpletest\UserCreationTrait;

/**
 * Base class for kernel tests for the message digest module.
 */
abstract class DigestTestBase extends KernelTestBase {

  use AssertMailTrait;
  use MessageTemplateCreateTrait;
  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'filter',
    'filter_test',
    'message',
    'message_digest',
    'message_digest_test',
    'message_notify',
    'system',
    'user',
  ];

  /**
   * Message notifier plugin manager.
   *
   * @var \Drupal\message_notify\Plugin\Notifier\Manager
   */
  protected $notifierManager;

  /**
   * The message notify sender service.
   *
   * @var \Drupal\message_notify\MessageNotifier
   */
  protected $notifierSender;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();
    $this->notifierManager = $this->container->get('plugin.message_notify.notifier.manager');
    $this->notifierSender = $this->container->get('message_notify.sender');
    $this->installEntitySchema('message');
    $this->installEntitySchema('user');
    $this->installSchema('message_digest', ['message_digest']);
    $this->installSchema('system', ['sequences']);
    $this->installConfig(['filter', 'filter_test', 'message_notify', 'system']);

    // Create a dummy user to avoid UID 1 super privileges.
    $this->createUser();
  }

}
